/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * CDKExtensions.java - Initial Developper : ofabre
 * -------------------------------------------------------------------------
 */
package org.objectweb.petals.component.common.util;

import java.util.List;
import java.util.Properties;

import org.objectweb.petals.common.util.XMLUtil;
import org.objectweb.petals.component.common.PEtALSCDKException;
import org.objectweb.petals.jbi.descriptor.Extensions;
import org.w3c.dom.DocumentFragment;
import org.w3c.dom.Node;

public class CDKExtensions extends Extensions {

	private final String PETALS_EXTENSIONS = "http://petals.objectweb.org/extensions/";

	private Extensions extensions;

	private Properties petalsExtensions;

	public CDKExtensions(Extensions extensions) {
		super();
		this.extensions = extensions;
		petalsExtensions = new Properties();
		loadExtensions(extensions.getDocumentFragment());
	}

	public void addPetalsExtension(final String key, final String value) {
		petalsExtensions.put(key, value);
	}

	public Properties getPetalsExtensions() {
		return petalsExtensions;
	}

	public DocumentFragment getDocumentFragment() {
		return extensions.getDocumentFragment();
	}

	public void setDocumentFragment(DocumentFragment documentFragment) {
		extensions.setDocumentFragment(documentFragment);
	}

	/**
	 * Extension nodes are nodes which names are different from those specified
	 * by JBI. This method load these extensions.
	 *
	 * @param node
	 *            an extension xml node
	 * @throws PEtALSCDKException
	 */
	private void loadExtensions(final Node node) {
		List<Node> children = XMLUtil.getNodeChildren(node);
		for (Node child : children) {
			// Load extension information
			String uriString = child.lookupNamespaceURI(child.getPrefix());
			// Check if the node uri is a PEtALS uri
			if (PETALS_EXTENSIONS.equals(uriString)) {
				loadPetalsKeyValueExtension(child);
			}

		}
	}

	private void loadPetalsKeyValueExtension(final Node child) {
		// treat key value nodes
		List<Node> children = XMLUtil.getNodeChildren(child);
		for (Node extChild : children) {
			addPetalsExtension(extChild.getNodeName(), XMLUtil
					.getTextContent(extChild));
		}
	}

}
